# Anchor annotator
Anchor annotator is a program for inspecting corpora for the [Montreal Forced Aligner](https://montreal-forced-aligner.readthedocs.io/en/latest/) and correcting transcriptions and pronunciations

```Keep your text anchored on the shifting seas of speech```

Please refer to the [documentation](https://anchor-annotator.readthedocs.io/en/latest/) for details on installation and use.
